# Prostate Cancer

## Epidemiology

* About 1 in 9 American men
* Second most common cancer in American men other than skin cancer
* About 15% - 17% of men older than 50 years with occult prostate cancer
* Nearly 70% of men older than 80 years harbor occult prostate cancer
* About 1 in 41 would die of prostate cancer
* Second leading cause of cancer death in American men

### Key points

* Prostate cancer is a common diagnosis, and although metastatic disease develops in a small percentage of affected patients, this translates into a large absolute number of deaths due to prostate cancer.
* Whether black men tend to have biologically more aggressive prostate cancer than nonblack men is controversial. Disparities in access to care likely explain at least some of the difference in outcomes.
* There is no clear causal link between vasectomy and prostate cancer, nor does testosterone supplementation appear to increase the risk of aggressive prostate cancer.

## Heredity

* 5% - 10% of all cases are hereditary
* HOXB13 G84E strongly associated with early-onset familial prostate cancer
* Germline alterations in DNA repair genes are more common in metastatic disease
* Deleterious germline mutations: BRCA2, ATM, CHEK2, BRCA1, RAD51D, PALB2
* Men with metastatic prostate cancer should undergo germline testing

| Gene      | Prostate cancer | Aggressive cancer | Early-onset | Specific outcomes        |
| --------- | --------------- | ----------------- | ----------- | ------------------------ |
| BRCA1     | 1.07 - 3.81     |                   | 1.82        | 5.16                     |
| BRCA2     | 3.18 - 8.6      | 3.18 - 4.38       | 7.33        | HR for death, 2.4 - 5.48 |
| MMR genes | 1.99 - 3.67     |                   | 2.48        |                          |
| HOXB13    | 2.8 - 8.47      |                   | 2.7 - 10.11 |                          |

NCCN recommends germline testing for:

* any patient with metastatic, regional, or high-risk localized prostate cancer, regardless of family history.
* patients with low- to intermediate-risk prostate cancer with intraductal histology (new in NCCN 2019 guidelines) or a “strong family history” of prostate cancer, meaning:
  * a brother or father or multiple family members diagnosed with prostate cancer at age \< 60 years
  * known family history of high-risk germline alterations
  * two or more relatives with breast, ovarian, or pancreatic cancer (suggesting BRCA2 alteration)
  * two or more relatives with colorectal, endometrial, gastric, ovarian, pancreatic, small-bowel, urothelial, kidney, or bile duct cancer (suggesting Lynch syndrome)
  * Ashkenazi Jewish ancestry, which could also prompt genetic testing

### Key points

* Prostate cancer is one of the most hereditable cancers. Clinicians should take a full history of malignancies in the family and be familiar with the link between prostate cancer and germline alterations in BRCA2 and mismatch repair genes, which are enriched among men with metastatic prostate cancer.
* Guidelines for referral to genetic counseling are frequently changing, but at minimum, clinicians should consider genetic counseling for all patients with metastatic castration-resistant prostate cancer (mCRPC), those with strong family histories as outlined in the preceding paragraphs, or those with alterations in DNA damage repair or mismatch repair genes identified from tumor sequencing.

## Anatomy

* Peripheral zone is palpable by DRE and is the site of origin of 70% of prostate cancers
* Transition zone surrounds the urethra and cannot be assessed by DRE
  * Up to 20% of all prostate cancers develop in the transition zone
  * BPH is more common than prostate cancer in the transition zone
* Anterior portion is generally not biopsied as part of routine prostate needle biopsy, and should be evaluated by either MRI or targeted/directed biopsy when PSA continues to rise in the setting of continued negative biopsy specimens
* If seminal vesicle involvement is suspected, then primary radiation + ADT is typically used in lieu of prostatectomy
  * If the bulk of positive specimens is from the base of the gland, consider obtaining MRI to look for seminal vesicle involvement
* Apical disease poses the problem of having a higher rate of positive surgical margins, harboring an anterior tumor, and incontinence
  * Patients with a bulk of pisitive specimens from the apex may not be optimal candidates for prostatectomy

### Key points

* Prostate cancer is typically diagnosed via TRUS biopsy using a standard 12-core template to sample the posterior peripheral zone.
* Anatomic location can help predict pattern of spread and treatment-related risks. Disease near the base of the gland may extend into the seminal vesicles. Disease in the apex may increase risk of positive surgical margins and urinary incontinence.

## Pathology and molecular pathogenesis

* Androgens are the primary regulators of prostate cancer cell growth/proliferation
* AR is located on Xq11-13
* Typical IHC profile
  * Negative for CK7 and CK20
  * Positive for AR and PSA
  * Positive for NKX3.1
    * NKX3.1 positivity is retained even in some advanced treatment-desistant prostate cancers that have lost AR/PSA expression
    * In cases of mass involving both prostate and bladder, NKX3.1 could help differentiate prostate cancer from urothelial cancer
* Gleason grading system and WHO prognostic groups
  * Gleason 3+3=6:	grade group 1
  * Gleason 3+4=7:	grade group 2
  * Gleason 4+3=7:	grade group 3
  * Gleason 8:		grade group 4
  * Gleason 9-10:	grade group 5
* Histology
  * Prostatic intraepithelial neoplasia: 50% would be diagnosed with prostate cancere in 5 years
  * More than 99% of prostate cancers are adenocarcinoma
  * \< 1% are pure ductal and mucinous variants
  * Small cell carcinoma and mesenchymal tymors (rhabdomyosarcomas in younger patients, leiomyosarcomas in older patients) are rare
  * Urothelial carcinomas of the prostate are confined to the periurethral ducts and more common among patients who have been successfully treated for non-muscle-invasive bladder cancer
  * Lymphomas and leukemias may rarely occur in the prostate gland
* During treatment of advanced prostate cancer, multiple genomic and transcriptomatic alterations could occur as mechanisms of treatment resistance
  * Most prostate cancers remain dependent on AR signaling
  * A subset may become "androgen indifferent" and are generally characterized by alterations in RB1 and p53
  * Some, but not all, of these tumors may exhibit neuroendocrine differentiation, with positive synaptophysin and/or chromogranin A staining
    * The extreme of neuroendocrine differentiation is "small cell" morphology, histologically similar to small cell carcinoma of the lung or other extrapulmonary sites
    * Neuroendocrine prostate cancer is associated with amplification of AURKA and MYCN, offering the opportunity for targeted therapy
    * Clinically, emergence of neuroendocrine differentiation and small cell transformation should be considered in men who develop castration-resistant disease after ADT for high-grade cancers, especially when visceral involvement is diagnosed and radiographic progression occurs in the absence of an increase in PSA

### Key points

* Prostate cancer can be characterized by its typical IHC profile: cytokeratin 7/20-negative, PSA-positive, AR-positive, and NKX3.1-positive.
* As treatment resistance occurs, different phenotypes may emerge. Most CRPC is still driven by AR signaling, even after developing resistance to subsequent AR-directed therapies.
* Some advanced CRPC may become “androgen indifferent,” often harboring alterations in Rb1 and p53. These may be admixed with AR-driven tumors. A subset of these cases may have neuroendocrine features, with the most extreme exhibiting small-cell morphology.
* Small-cell prostate cancer is a rare subset and classically occurs with rapid visceral spread in the absence of increase in serum PSA level after a period of hormonal therapy for highgrade initial disease (de novo small-cell prostate cancer is extremely rare). It is characterized primarily by morphology, but it can also be positive on synaptophysin and/or chromogranin A staining.

## Prevention

* There is no cut point of PSA levels above or below which indicates the presence or absence of prostate cancer
* There is a continuum of risk according to PSA levels
* Despite PSA screening studies involving hundreds of thousands of men, none has demonstrated a conclusive improvement in overall survival as a result of screening
* PSA is prostate specific but not prostate cancer specific
  * Half-life of PSA is 2-3 days
  * Levels should remain undetectable if the prostate has been removed
  * PSA > 4 ng/mL has predictive value for diagnosis of prostate cancer, but lower PSA values may also be associated with prostate cancer as well as high-grade cancers
  * For men with PSA between 4 and 10, PSA velocity of at least 0.75 ng/mL/y is suspicious for cancer
  * Measurements should be made on at least 3-4 consecutive occasions, usually separated by 6 months, over at least 12-18 months
  * Persistence or increase of PSA while using 5-α reductase inhibitors (finasteride, dutasteride) could be associated with prostate cancer
* Abnormal DRE necessitates referral to urologist for additional diagnostic evaluation (i.e. TRUS biopsy)
* MRI guidance may be useful as first diagnostic step

### Key points

* There are no universally accepted protocols for prostate cancer prevention or screening.
* 5-α Reductase inhibitors decrease the incidence of prostate cancer but thus far have not shown a convincing reduction in prostate cancer–specific mortality rate. There is some ongoing concern about 5-α reductase inhibitors increasing risk of highgrade prostate cancer.
* PSA-based prostate cancer screening has shown, at most, a small reduction in prostate cancer–specific mortality rate and no convincing effect on overall mortality. Screening could be more effective if targeted to higher-risk men and to the age groups most likely to benefit—younger men, rather than older men—but further studies evaluating this are underway.
* For men undergoing evaluation for elevated PSA concentration, a prebiopsy MRI may help triage who requires biopsy, limiting biopsies to those with a greater likelihood of clinically significant cancer. However, this is not yet standard of care, and longer-term follow-up will be needed to see whether omitting standard 12-core biopsies in a patient with no highgrade lesions on MRI (appropriately performed and interpreted) risks under-diagnosis of clinically significant cancer.
* When clinicians have adopted MRI-targeted biopsies thus far, it has typically been in one of two scenarios: (1) to supplement the standard 12-core biopsy approach, or (2) if PSA level increases significantly in the absence of aggressive disease in standard core biopsy specimens, or negative standard biopsy specimens, possibly indicating a possible anterior gland tumor.

## Tumor staging

* Clinical T stage is assigned by DRE
* Pathologic T stage is assigned based on examination of a radical prostatectomy specimen
* Tumors detected in a biopsy specimen on the basis of elevated PSA and no palpable disease by DRE are designated T1c
* T2 disease is confined to the prostate
* T3 tumor extends through the prostate capsula (T3a) or invades the seminal vesicles (T3b)
* T4 tumors invade adjacent structures or organs

## Risk stratification

* Localized prostate cancer is clinically heterogeneous
* Prognostic models based on initial T stage, Gleason score, and baseline PSA
* AJCC8 includes prognostic groupings including anatomic stage and PSA

|                | Low                 | Intermediate favorable | Intermediate unfavorable | High                                                                                                         |
| -------------- | ------------------- | ---------------------- | ------------------------ | ------------------------------------------------------------------------------------------------------------ |
| Gleason        | 3+3                 | 3+4                    | 4+3                      | 4+4, any 5                                                                                                   |
| T stage        | (AND) T1 - T2a      | (OR) T2b - T2c         | (OR) T2 - T3             | (OR) T3                                                                                                      |
| PSA            | (AND) \< 10         | (OR) 10 - 20           |                          | (OR) > 20                                                                                                    |
| Cores involved |                     | (AND) \< ½             | (OR) > ½                 |                                                                                                              |
| Plan           | Active surveillance | \<--                   | \-->                     | Definitive therapy                                                                                           |
|                |                     |                        |                          | Radical prostatectomy OR (Radiotherapy + 4-6 months ADT if unfavorable risk + 18-24 months ADT if high risk) |

- Role of imaging in staging
  - Staging imaging typically consists of CT or MRI of the abdomen and pelvis, plus bone scan
  - Low-risk disease: no routine staging imaging
  - Intermediate-risk disease: if 2 of 3 risk factors present
    - Palpable nodule on DRE (cT2)
    - Gleason score 7
    - PSA concentration > 10 ng/mL
  - High-risk disease: all patients
- Management by risk
  - Tumors confined to the prostate are generally managed by radical prostatectomy, radiotherapy, or in some cases active surveillance
    - Treatment decision should be made based on life expectancy, overall health status, and tumor characteristics
    - Patients with life expectancy < 5 years do not benefit from treatment of low-risk prostate cancer and therefore should undergo watchful waiting, with additional workup when patient becomes symptomatic
  - Very low risk: active surveillance
  - Low risk localized
    - Active surveillance
    - Interstitial prostate brachytherapy (avoid in patients with significant LUTS or recurrent UTI/prostatitis)
    - EBRT
    - Radical prostatectomy
  - Intermediate and high-risk localized: if life expectancy ≥ 5 years (intermediate) or ≥ 10 years (high risk)
    - Radiotherapy
    - Prostatectomy
  - Regional node-positive N1 stage IVA (nodes above aortic bifurcation considered M1 stage IVB)
    - Definitive radiotherapy to prostate and pelvic nodes + long-course ADT
    - Prostatectomy + extended lymphadenectomy + adjuvant radiotherapy + adjuvant ADT

### Key points

- Patients with localized prostate cancer can be risk-stratified on the basis of three clinical factors: T stage, Gleason score, and PSA level. Genomic testing of the cancer specimen may provide additional information about risk and progression, but this is not yet prospectively validated for decision-making.
- Prostatectomy, RT, and ADT all have unique adverse effect profiles. Prostatectomy can lead to urinary incontinence and erectile dysfunction, but it can help improve significant obstructive symptoms. Radiation tends to lead to irritative urine and bowel symptoms. ADT can cause vasomotor symptoms, fatigue, loss of libido, weight gain, muscle loss, and bone thinning, most of which reverse after discontinuation of ADT and recovery of testosterone.

## Treatment modalities

- Watchful waiting
  - No therapeutic intervention until symptomatic progression
  - No monitoring of PSA or serial biopsies
  - Appropriate for patients with limited life expectancy, based on age/comorbidities
- Active surveillance
  - Delayed intention to treat
  - Scheduled PSA testing, DREs, and periodic prostate needle biopsies (most protocols require repeated biopsy at 1 year)
  - Treat if/when changes in Gleason score, tumor volume, or serum PSA suggest increasing disease activity
- Radical prostatectomy
  - Complete excise the cancer while maintaining urinary control and preserving potency
  - PSA levels should decline to undetectable; any detectable or increasing PSA after prostatectomy is indication of residual or recurrent cancer
  - Cancer control is assessed by PSA relapse-free survival, time to objective progression, cancer-specific survival, and overall survival
  - Most men experience erectile dysfunction after radical prostatectomy
  - Urinary incontinence more commonly result in poorer QoL and regret
- Radiation therapy
  - EBRT, implanted radioactive seeds, or both + adjuvant ADT
  - Stereotactic radiosurgery offers hypofractionated schedule with similar efficacy as standard EBRT
  - Proctitis is often self-limited
    - Could be treated with steroid or mesalamine suppositories
    - Small increase in rectal cancer incidence
  - Cystitis could be treated with NSAIDs or hyperbaric oxygen if refractory
- Focal therapy
  - Cryosurgery
    - Minimally invasive procedure for local control
    - For disease not suitable for radical surgery or local recurrences after radiotherapy
  - High-intensity focused ultrasound (hyperthermia therapy)
    - Available data do not demonstrate significant improvement compared with surgery
    - Significant increase of residual tumor in treated areas 2 years after initial treatment
- Neoadjuvant and adjuvant ADT
  - Neoadjuvant ADT before surgery reduces rate of positive surgical margins, but did not influence overall outcomes in older trials
  - Neoadjuvant and concurrent ADT provide OS benefit with radiotherapy in patients with high-risk disease
    - Optimal duration of ADT not well-defined
    - Typical course is 18-24 months
  - Addition of ADT to RT not shown to improve OS in intermediate-risk disease, but improves biochemical DFS with 4-6 months of ADT
    - Typical course is 4-6 months
  - Timing of ADT relative to RT does not appear to affect long-term outcomes
    - ADT is typically started 2 months before RT
    - Some clinicians add bicalutamide for first 4-6 months of ADT or until RT is completed, especially in high-risk disease, but it is uncertain whether adding bicalutamide improves outcomes

### Key points

- Patients with low-risk disease may be offered active surveillance, which uses serial PSA measurements, DREs, and biopsy specimens to detect any presence of higher-risk disease, at which point definitive therapy can be offered. Sequential MRI may also be helpful. This strategy results in less treatmentassociated morbidity and similar long-term cancer survival compared with immediate therapy.
- Patients with intermediate- and high-risk disease typically should receive definitive therapy, assuming a life expectancy of at least 5 (high-risk) to 10 (intermediate-risk) years (or if symptomatic). Definitive therapies include radical prostatectomy and RT. Long-term cancer survival is similar with either strategy, but adverse effect profiles differ.
- For patients with intermediate- or high-risk disease undergoing RT, the addition of ADT improves biochemical DFS (intermediate risk) and OS (high risk). Duration is typically 4 to 6 months for intermediate-risk disease and 18 to 24 months for high-risk disease. ADT may be optional for favorable intermediate-risk disease.
- Patients with clinical or pathologic (biopsy specimen) evidence of pelvic lymph node involvement are typically treated with definitive RT plus long-course ADT, although no randomized data exist, and prostatectomy followed by adjuvant RT and ADT may also be an option.
- Patients with preexisting urinary symptoms should avoid brachytherapy and may experience symptomatic benefit from radical prostatectomy.
- There is little to no advantages for robotic prostatectomy versus other surgical approaches and for proton therapy versus conventional RT for clinically localized prostate cancer.

## Therapy for recurrent or advanced disease

- Pathologic node-positive disease
  - Positive lymph nodes at time of prostatectomy indicates aggressive disease at high risk of recurrence
  - Adjuvant ADT improves OS and prostate cancer specific survival in patients with positive lymph nodes at time of prostatectomy
  - Immediate adjuvant RT may be better than delayed (salvage) RT if risk is sufficiently high to justify some overtreatment of patients in whom disease would never have occurred
- Biochemical recurrence
  - Increasing PSA level without radiograph-detectable metastases after radical prostatectomy, radiotherapy, or both
    - Any detectable PSA after radical prostatectomy
    - PSA increase by 2 ng/dL above nadir after RT (Phoenix criteria)
      - PSA may transiently increase after RT because of testosterone recovery or prostate inflammation
  - Management
    - BCR post-RP
      - Adjuvant or salvage RT ± ADT ×6 months → surveillance
    - BCR post-RT
      - Rule out metastasis or local recurrence → salvage local therapies → surveillance
    - Increasing PSA without metastases
      - Observation
      - Indefinite ADT (continuous or intermittent)
    - Distant metastases
      - MCSPC
      - Metastasis-directed therapy ± ADT ± ASI

## Next: 14-2.10.3: Local Failure
